@@ -487,6 +487,14 @@ mod imp {
                 self.model.set_continuous(continuous);
             }
 
+            // Fullscreen
+            if let Some(fullscreen) = metadata.boolean("fullscreen") {
+                self.parent_window()
+                    .dynamic_cast::<gio::ActionGroup>()
+                    .unwrap()
+                    .change_action_state("fullscreen", &fullscreen.into());
+            }
+
             // Dual page
             if let Some(dual_page) = metadata.boolean("dual-page") {
                 let page_layout = if dual_page {
@@ -795,8 +803,7 @@ impl PpsDocumentView {
     }
 
     pub fn handle_annot_popup(&self, annot: &impl IsA<Annotation>) {
-        self.imp()
-            .view_menu_annot_popup(Some(annot.as_ref().clone()));
+        self.imp().view_menu_annot_popup(Some(annot.as_ref()));
     }
 
     pub fn model(&self) -> DocumentModel {
