@@ -126,7 +126,7 @@ impl imp::PpsDocumentView {
     fn print_cancel_alert_response(&self, response: &str) {
         match response {
             "close-later" => {
-                if self.print_queue.borrow().len() == 0 {
+                if self.print_queue.borrow().is_empty() {
                     self.parent_window().destroy();
                 } else {
                     self.close_after_print.set(true);
@@ -134,7 +134,7 @@ impl imp::PpsDocumentView {
             }
             "force-close" => {
                 self.close_after_print.set(true);
-                if self.print_queue.borrow().len() != 0 {
+                if !self.print_queue.borrow().is_empty() {
                     self.obj().set_sensitive(false);
                     self.print_cancel();
                 }
@@ -400,7 +400,11 @@ impl imp::PpsDocumentView {
     }
 
     #[template_callback]
-    fn view_handle_link(&self, link: &papers_document::Link, backlink: &papers_document::Link) {
+    fn view_handle_link(
+        &self,
+        link: &papers_document::Link,
+        backlink: Option<&papers_document::Link>,
+    ) {
         let mut new_link = None;
 
         if link.title().is_none() {
@@ -427,7 +431,10 @@ impl imp::PpsDocumentView {
             }
         }
 
-        self.history.add_link(backlink);
+        if let Some(backlink) = backlink {
+            self.history.add_link(backlink);
+        }
+
         self.history.add_link(new_link.as_ref().unwrap_or(link));
     }
 
